
; The base I/O addresses of the stardard primary and secondary
; ATA interface channels.
;
IOBASE1 equ 1f0h
IOBASE2 equ 170h

; The offsets of the necessary Command/Control Block registers
; from the base I/O address. The Data Register is 16 bits wide
; and accessed through a 16-bit I/O port. All other registers
; are 8 bits wide and accessed through 8-bit I/O ports.
;
DATA_OFFSET         equ 0       ; Data Register
SECTOR_COUNT_OFFSET equ 2       ; Sector Count Register
CYL_LOW_OFFSET      equ 4       ; Cylinder Low Register
CYL_HIGH_OFFSET     equ 5       ; Cylinder High Register
DEVICE_HEAD_OFFSET  equ 6       ; Device/Head Register
COMMAND_OFFSET      equ 7       ; Command Register (write)
STATUS_OFFSET       equ 7       ; Status Register (read)
ALT_STATUS_OFFSET   equ 206h    ; Alternate Status Register (read)

; The necessary Command/Control Block bit masks. The status
; register IDX bit is not supported for all devices and/or
; interfaces.
;
DEVICE_HEAD_DEV_MASK  equ 10h   ; Device (0=master,1=slave)
STATUS_ERR_MASK       equ 1     ; Last command returned an error
STATUS_IDX_MASK       equ 2     ; Active once per revolution
STATUS_DRQ_MASK       equ 8     ; Data Request (ready for transfer)
STATUS_DRDY_MASK      equ 40h   ; Device Ready (to accept a command)
STATUS_BSY_MASK       equ 80h   ; Device Busy

; The Identify Device command codes.
;
ATA_IDENTIFY_DEVICE   equ 0ECh
ATAPI_IDENTIFY_DEVICE equ 0A1h

; The ATAPI signature. This signature is returned in the cylinder
; high and cylinder low registers by an ATAPI device in response
; to an ATA Identify Device command.
;
ATAPI_SIGNATURE_HIGH  equ 0EBh
ATAPI_SIGNATURE_LOW   equ 014h

; Error code values returned by the IdDevice procedure.
;
ID_ERROR_NO_DEVICE     equ 1
ID_ERROR_TIMEOUT_BSY   equ 2
ID_ERROR_TIMEOUT_NODRQ equ 3
ID_ERROR_UNEXPECTED    equ 4
